@@ -440,7 +440,7 @@ class Base(Controller):
             (['-F','--file'],{
                 "help": "File containing metadata",
                 "action": "store",
-                "default": "/home/jakub/data/asco/devices.csv"
+                "default": "/home/jakub/data/devices.csv"
             })
         ]
     )
