@@ -156,7 +156,8 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     if target in ['0', '-1']:
         if filter: 
             df = add_metadata(df, metadata_file)
-            print(df[['dongle_id','drive','time','seg_num','Registration Number']])
+            target_columns = ['dongle_id','drive','time','seg_num','Registration_Number', 'Logistics_Firm']
+            print(df[target_columns])
         else: print(df[['dongle_id','drive','time','seg_num']])
     else:
         df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
@@ -191,7 +192,11 @@ def add_metadata(df: pd.DataFrame, metadata_file_path: str):
         return df
 
     meta_data = pd.read_csv(metadata_file_path)
+    meta_data.columns = [x.replace(' ', '_') for x in meta_data.columns]
+    
+    # remove all rows with na in Dongle_ID
+    meta_data = meta_data[~meta_data.Dongle_ID.isna()]
 
     # merge the two dataframes
-    df = df.merge(meta_data, left_on='dongle_id', right_on="Dongle ID")
+    df = df.merge(meta_data, left_on='dongle_id', right_on="Dongle_ID")
     return df
\ No newline at end of file
